function mufftres(varargin)
%
% usage MUFFTRES(LB)
% FFT of residues (data-fit)
% with hypergaussian window of width LB (in mus^-1).
% A satisfactory fit must be performed first, with MUFIT.
% Hint: choose LB close to the relaxation rate of the component
% you want to see.
%
% usage MUFFTRES(LB,N)
% residues are calculated subtracting only components n
% (e.g. in fit bamumu, MUFFTRES(LB,[1 3]) will subtract from the
% data the best fit, setting to zero the parameters of the second 
% component, mu) 
%
% usage MUFFTRES(LB,N,RANGEFFT)
% RANGEFFT is the range to be displayed (in MHz, e.g. [1 50])

    global MU_MODEL_F
    global MU_FIG
    global MU_ADD
    global MU_DATA
    
    rangefft=[];
    if ~isfield(MU_MODEL_F,'CHI')
        disp('Fit not present')
    else
        n=1:length(MU_MODEL_F.COMPONENTNUMBER);
        switch length(varargin)
          case 0
            lb=0;
          case 1
            lb=cell2mat(varargin);
          case 2
            lb=cell2mat(varargin(1));
            n=cell2mat(varargin(2));
          case 3
            lb=cell2mat(varargin(1));
            n=cell2mat(varargin(2));
            rangefft=cell2mat(varargin(3));
        end
        [mupout dum parname pf]=mupar(1,n);
        range=MU_MODEL_F.RANGE;
        t=MU_DATA.TIME(range(1):range(2)); % time
        y=MU_DATA.ASYMMETRY(range(1):range(2))-fcn(mupout,t); % residues
        ey=MU_DATA.ASYMERROR(range(1):range(2));
        % extrapolate to nearly t=0
        nt0=round(t(1)/(t(2)-t(1)));
        dt=t(2)-t(1);
        dfr=1/t(end); % real frequency resolution
        t=[t(1)-dt*[nt0:-1:1] t]; % time extrapolated to t~0
        l=length(t);
        n=2^(round(log2(l))+1); % nearly doubled range, power of 2
        % zero padding to n
        t=[t t(end)+dt*[1:n-l]]; % extended time
        filter=exp(-(t*lb).^3);
        filter=filter/sum(filter)/dt; % approx normalization
        % try hypergauss n=3, varying exponent
        y=[zeros(1,nt0) y zeros(1,n-l)]; %  zero padded residues
        y=y.*filter; % filtered residue
        ey=[zeros(1,nt0) ey zeros(1,n-l)]; %  zero padded errore
        ey.*filter;
        a=fft(y); % amplitudes
        df=1/t(end); % apparent frequency resolution
        f=[0:n/2-1]*df; %positive frequencies
        % supposing it is in phase (not true for TF) 
        if ~isempty(rangefft)
            start=max(find(f<=rangefft(1)));
            start=max([start 1]);
            stop=min(find(f>=rangefft(2)));
            stop=min([stop n/2-1]);
        else
            start=1;
            stop=find(f==max(f));
        end
        f=f(start:stop);
        ar=real(a(start:stop)); 
        ai=imag(a(start:stop)); 
% noise in the FFT: data, tn, yn with standard deviations eyn 
% FFT ampli am=sum_n yn exp(i wm tn) 
% => eam^2=sum_n |exp(i wm tn)|^2 eyn^2 = sum_n eyn^2 uniform
% ea is a distance, hence the radius of one standard deviation
% both ai and ar have the same sigma=ea
% hence ap has sigma=sqrt(2)*ea 
        ea=sqrt(sum(ey.^2))*ones(size(ai)); % noise level

        ap=ai.^2+ar.^2; % power
        % ab=sqrt(ab); % absolute value
        figure(MU_FIG.FFT)
        set(MU_FIG.FFT,'Name',MU_FIG.FFTNAME,'Visible','off',...
              'MenuBar','None');
        clf
        
        empty=[];
        Xmin=0.085;
        Ymin=0.1;
        Ywidth=0.3;
        Xwidth=0.8-Xmin;
        Ywidth=(0.92-Ymin)/3;
        hiamp=axes('position',[Xmin Ymin Xwidth Ywidth]);
        
        %        roff=max(ar)*1.3;
        
        x=[f f(end:-1:1)];
        plot(f,ai,'b',f,zeros(size(f)),'b-',...
             f,ea,'b--',f,-ea,'b--',f,2*ea,'b:',f,-2*ea,'b:')
        hold on
        yb=min(ai,ea);
        y=[ai yb(end:-1:1)];
        fill(x,y,'b')
        yb=max(ai,-ea);
        y=[ai yb(end:-1:1)];
        fill(x,y,'b')
        hold off
        xy=axis;
        axis([min(f) max(f) [min(ai) max(ai)]*1.1])        
        ytl=get(gca,'yticklabel');
        ylt=str2num(ytl(end));
        dytl=ylt-str2num(ytl(end-1));
        if xy(4)-ylt<dytl*0.4, ytl(end,1:end)=' '; end
        set(gca,'yticklabel',ytl);
        xlabel('\nu (MHz)')
        ylabel('Imag Amp.')

        hramp=axes('position',[Xmin Ymin+Ywidth Xwidth Ywidth]);

        plot(f,ar,'r',f,zeros(size(f)),'r-',...
             f,ea,'r--',f,-ea,'r--',f,2*ea,'r:',f,-2*ea,'r:')
        yb=min(ar,ea);
        y=[ar yb(end:-1:1)];
        hold on
        fill(x,y,'r')
        yb=max(ar,-ea);
        y=[ar yb(end:-1:1)];
        fill(x,y,'r')
        xy=axis;
        axis([min(f) max(f) [min(ar) max(ar)]*1.1])
        ytl=get(gca,'yticklabel');
        ylt=str2num(ytl(end));
        dytl=ylt-str2num(ytl(end-1));
        if xy(4)-ylt<dytl*0.4, ytl(end,1:end)=' '; end 
        set(gca,'yticklabel',ytl);
        set(gca,'xticklabel',empty)%,'yaxislocation','right')
        ylabel('Real Amp.')
        hold off
        
        hpow=axes('position',[Xmin Ymin+2*Ywidth Xwidth Ywidth]);
        
        lw=2;
        da=0.2;
        eap=2*ea.*sqrt(ap);
        plot(f,ap,'m',f,eap,'m--',f,2*eap,'m:',f,-2*eap,'m:')
        yb=min(ap,eap);
        y=[ap yb(end:-1:1)];
        hold on
        fill(x,y,'m')
        plot(f(stop-start)*0.95-[lb 0],max(ap)*([0.9 0.9]),'m-',...
             'linewidth',lw)
 % f(stop)*0.95-[df 0],max(ap)*[1 1],'m-',f(stop)*0.95-[dfr 0],max(ap)*([1 1]-da),'m-',...
        hold off
        set(gca,'xticklabel',empty)
        ylabel('Power (a.u.)')

        xy=axis;
        xy=[min(f) max(f) 0 max(ap)*1.1];
        axis(xy);
        dy=xy(4)-xy(3);
        ytext=xy(4)+0.06*dy;
        dtext=(xy(2)-xy(1))*0.02;
        if isempty(MU_ADD)
            runs=int2str(MU_DATA.NRUN);
        else
            l=length(MU_ADD);
            runs=[int2str(MU_DATA.NRUN) '+' int2str(MU_ADD)];
        end
        blue=[.2 .2 .8];
        fsiz=11;
        text(xy(1)-dtext,ytext,[runs '   ' MU_DATA.SAMPLE ...
                   MU_DATA.TEMPERATURE ' ' MU_DATA.FIELD ...
                    ' ' MU_DATA.ORIENTATION] ...
             ,'fontsize',fsiz,'fontweight','demi','color',blue)
        fsizlab=20;
        text(xy(2)+3*dtext,ytext+0.02*dy,'\mu lab',...
             'fontsize',fsizlab,'fontweight','demi',...
             'fontname','Arial','color',blue);
        ytext=xy(3)+0.82*dy;
        text(xy(2)+dtext,ytext,['LB=' num2str(lb) ' {\mu}s^{-1}'],...
              'fontsize',fsiz,'fontweight','demi','color',blue)
        ytext=xy(3)+0.66*dy;
        text(xy(2)+dtext,ytext,['\alpha=' num2str(MU_MODEL_F.ALPHA) ...
                   ],'fontsize',8);
        ytext=xy(3)+0.5*dy;
        text(xy(2)+dtext,ytext,['F:[' musgroup(1,0) ']'],'fontsize',8);
        ytext=xy(3)+0.38*dy;
        text(xy(2)+dtext,ytext,['B:[' musgroup(2,0) ']'],'fontsize', ...
             8);
        mupbf=mupar; % to get the full fit parameter values
        l=length(mupout);
        ytop=0.22*dy;
        ybottom=-2*dy;
        dy=(ytop-ybottom)/l;
        %        ytop=xy(3)+ytop;
        ll=0;
%         ip=findstr(parname,' ');
%         ipt=ip(1:end)+1; % start of k-th parname 
%         ipp=ip(2:end)-1; 
%         ipp=[ipp length(parname)]; % stop of k-th parname 
%         for k=1:l
%             ytext=ytop-ll*dy;
%             ll=ll+1;
%             if mupout(k)~=0
%                 text(xy(2)+dtext,ytext,[parname(ipt(k):ipp(k)) ...
%                                     '=' num2str(mupbf(k),3)],...
%                      'BackgroundColor',[.9 .7 .7])
%             else
%                 text(xy(2)+dtext,ytext,[parname(ipt(k):ipp(k)) ...
%                                     '=' num2str(mupbf(k),3)])
%            end
        for k=1:l
            ytext=ytop-ll*dy;
            ll=ll+1;
            if mupout(k)~=0
                text(xy(2)+dtext,ytext,[cell2mat(parname(k)) ...
                                    '=' num2str(mupbf(k),3)],...
                     'BackgroundColor',[.9 .7 .7])
            else
                text(xy(2)+dtext,ytext,[cell2mat(parname(k)) ...
                                    '=' num2str(mupbf(k),3)])
            end
        end    
    end
    set(MU_FIG.FFT,'Visible','on')


